#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh

# needed for opkg to function properly
export PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin
export SHELL=/bin/sh

LOGDIR="/var/log/dss11-websetup"
mkdir -p $LOGDIR 1>&2 >/dev/null

echo "Content-Type: application/json"
echo ""

if [[ ! -x /usr/bin/opkg ]]; then
    json_error $ERR_SETUP "opkg package manager is missing!"
    exit 1
fi

if [[ ! -x /usr/bin/addon ]]; then
    json_error $ERR_SETUP "addon wrapper script is missing!"
    exit 1
fi

if [[ -e /var/lock/systemupdate ]]; then
    json_error $ERR_DOWAIT "Update application busy, please try again later"
    exit 1
fi

if [[ "$1" == "list" ]]; then
    opkg2json -l
elif [[ "$1" == "list-installed" ]]; then
    opkg2json -i
elif [[ "$1" == "list-upgradable" ]]; then
    opkg2json -u
elif [[ "$1" == "addon-list" ]]; then
    addon2json -l
elif [[ "$1" == "addon-list-installed" ]]; then
    addon2json -i
elif [[ "$1" == "addon-list-upgradable" ]]; then
    addon2json -u
elif [[ "$1" == "update" ]] || [[ "$1" == "upgrade" ]] || 
     [[ "$1" == "addon-update" ]] || [[ "$1" == "addon-upgrade" ]] ||
     [[ "$1" == "addon-remove" ]] || [[ "$1" == "addon-install" ]]; then

    if [[ "$1" == "addon-install" ]]; then
        DISCLAIMER_ACCEPTED="no"
        if [[ -e /www/scripts/disclaimer.cfg ]]; then
            . /www/scripts/disclaimer.cfg
        fi
        if [[ "$DISCLAIMER_ACCEPTED"  != "yes" ]]; then
            json_error $ERR_DISCLAIMER "Please accept the disclaimer before installing apps"
            exit 1
        fi
    fi
    echo "[`date`] Starting update script (\"$1\")" --- >> "$LOGDIR/update.log"
    nohup /www/scripts/doupdate.sh "$1" "$2" >> "$LOGDIR/update.log" &
    if [[ "$?" -eq "$ERR_OK" ]]; then
        json_ok "OK"
        exit 0
    else
        json_error $ERR_UPDATE "Failed to start package manager process!"
        exit 1
    fi

else 
    json_error $ERR_PARAM "Invalid option given!"
fi

